pub fn origin_is_allowed(origin: &HeaderValue, allowed: &[HeaderValue]) -> boolExpand description
Returns true if origin matches any entry in allowed. Supports bare *
(any origin), exact match, and wildcard subdomains (*.example.com).
pub fn origin_is_allowed(origin: &HeaderValue, allowed: &[HeaderValue]) -> boolReturns true if origin matches any entry in allowed. Supports bare *
(any origin), exact match, and wildcard subdomains (*.example.com).